<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => '安道爾陪士特',
        ],
        'AED' => [
            0 => 'AED',
            1 => '阿拉伯聯合大公國迪爾汗',
        ],
        'AFA' => [
            0 => 'AFA',
            1 => '阿富汗尼 (1927–2002)',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => '阿富汗尼',
        ],
        'ALK' => [
            0 => 'ALK',
            1 => '阿爾巴尼亞列克 (1946–1965)',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => '阿爾巴尼亞列克',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => '亞美尼亞德拉姆',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => '荷屬安地列斯盾',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => '安哥拉寬扎',
        ],
        'AOK' => [
            0 => 'AOK',
            1 => '安哥拉寬扎 (1977–1990)',
        ],
        'AON' => [
            0 => 'AON',
            1 => '安哥拉新寬扎 (1990–2000)',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => '安哥拉新調寬扎 (1995–1999)',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => '阿根廷奧斯特納爾',
        ],
        'ARL' => [
            0 => 'ARL',
            1 => '阿根廷披索 (1970–1983)',
        ],
        'ARM' => [
            0 => 'ARM',
            1 => '阿根廷披索 (1881–1970)',
        ],
        'ARP' => [
            0 => 'ARP',
            1 => '阿根廷披索 (1983–1985)',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => '阿根廷披索',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => '奧地利先令',
        ],
        'AUD' => [
            0 => 'AU$',
            1 => '澳幣',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => '阿路巴盾',
        ],
        'AZM' => [
            0 => 'AZM',
            1 => '亞塞拜然馬納特 (1993–2006)',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => '亞塞拜然馬納特',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => '波士尼亞-赫塞哥維納第納爾',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => '波士尼亞-赫塞哥維納可轉換馬克',
        ],
        'BAN' => [
            0 => 'BAN',
            1 => '波士尼亞-赫塞哥維納新第納爾',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => '巴貝多元',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => '孟加拉塔卡',
        ],
        'BEC' => [
            0 => 'BEC',
            1 => '比利時法郎（可轉換）',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => '比利時法郎',
        ],
        'BEL' => [
            0 => 'BEL',
            1 => '比利時法郎（金融）',
        ],
        'BGL' => [
            0 => 'BGL',
            1 => '保加利亞硬列弗',
        ],
        'BGM' => [
            0 => 'BGM',
            1 => '保加利亞社會黨列弗',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => '保加利亞新列弗',
        ],
        'BGO' => [
            0 => 'BGO',
            1 => '保加利亞列弗 (1879–1952)',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => '巴林第納爾',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => '蒲隆地法郎',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => '百慕達幣',
        ],
        'BND' => [
            0 => 'BND',
            1 => '汶萊元',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => '玻利維亞諾',
        ],
        'BOL' => [
            0 => 'BOL',
            1 => '玻利維亞玻利維亞諾 (1863–1963)',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => '玻利維亞披索',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => '玻利維亞幕多',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => '巴西克魯薩多農瓦 (1967–1986)',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => '巴西克魯賽羅 (1986–1989)',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => '巴西克魯賽羅 (1990–1993)',
        ],
        'BRL' => [
            0 => 'R$',
            1 => '巴西雷亞爾',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => '巴西克如爾達農瓦',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => '巴西克魯賽羅 (1993–1994)',
        ],
        'BRZ' => [
            0 => 'BRZ',
            1 => '巴西克魯賽羅 (1942 –1967)',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => '巴哈馬元',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => '不丹那特倫',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => '緬甸基雅特',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => '波札那普拉',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => '白俄羅斯新盧布 (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => '白俄羅斯盧布',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => '白俄羅斯盧布 (2000–2016)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => '貝里斯元',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => '加幣',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => '剛果法郎',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => '歐元 (WIR)',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => '瑞士法郎',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => '法郎 (WIR)',
        ],
        'CLE' => [
            0 => 'CLE',
            1 => '智利埃斯庫多',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => '卡林油達佛曼跎',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => '智利披索',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => '人民幣（離岸）',
        ],
        'CNX' => [
            0 => 'CNX',
            1 => 'CNX',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => '人民幣',
        ],
        'COP' => [
            0 => 'COP',
            1 => '哥倫比亞披索',
        ],
        'COU' => [
            0 => 'COU',
            1 => '哥倫比亞幣 (COU)',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => '哥斯大黎加科朗',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => '舊塞爾維亞第納爾',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => '捷克斯洛伐克硬克朗',
        ],
        'CUC' => [
            0 => 'CUC',
            1 => '古巴可轉換披索',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => '古巴披索',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => '維德角埃斯庫多',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => '賽普勒斯鎊',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => '捷克克朗',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => '東德奧斯特馬克',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => '德國馬克',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => '吉布地法郎',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => '丹麥克朗',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => '多明尼加披索',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => '阿爾及利亞第納爾',
        ],
        'ECS' => [
            0 => 'ECS',
            1 => '厄瓜多蘇克雷',
        ],
        'ECV' => [
            0 => 'ECV',
            1 => '厄瓜多爾由里達瓦康斯坦 (UVC)',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => '愛沙尼亞克朗',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => '埃及鎊',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => '厄立特里亞納克法',
        ],
        'ESA' => [
            0 => 'ESA',
            1 => '西班牙比塞塔（會計單位）',
        ],
        'ESB' => [
            0 => 'ESB',
            1 => '西班牙比塞塔（可轉換會計單位）',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => '西班牙陪士特',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => '衣索比亞比爾',
        ],
        'EUR' => [
            0 => '€',
            1 => '歐元',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => '芬蘭馬克',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => '斐濟元',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => '福克蘭群島鎊',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => '法國法郎',
        ],
        'GBP' => [
            0 => '£',
            1 => '英鎊',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => '喬治亞庫旁拉里',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => '喬治亞拉里',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => '迦納賽地 (1979–2007)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => '迦納塞地',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => '直布羅陀鎊',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => '甘比亞達拉西',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => '幾內亞法郎',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => '幾內亞西里',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => '赤道幾內亞埃奎勒',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => '希臘德拉克馬',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => '瓜地馬拉格查爾',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => '葡屬幾內亞埃斯庫多',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => '幾內亞比索披索',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => '圭亞那元',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => '港幣',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => '洪都拉斯倫皮拉',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => '克羅埃西亞第納爾',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => '克羅埃西亞庫納',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => '海地古德',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => '匈牙利福林',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => '印尼盾',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => '愛爾蘭鎊',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => '以色列鎊',
        ],
        'ILR' => [
            0 => 'ILR',
            1 => '以色列謝克爾 (1980–1985)',
        ],
        'ILS' => [
            0 => '₪',
            1 => '以色列新謝克爾',
        ],
        'INR' => [
            0 => '₹',
            1 => '印度盧比',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => '伊拉克第納爾',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => '伊朗里亞爾',
        ],
        'ISJ' => [
            0 => 'ISJ',
            1 => '冰島克朗 (1918–1981)',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => '冰島克朗',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => '義大利里拉',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => '牙買加元',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => '約旦第納爾',
        ],
        'JPY' => [
            0 => '¥',
            1 => '日圓',
        ],
        'KES' => [
            0 => 'KES',
            1 => '肯尼亞先令',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => '吉爾吉斯索姆',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => '柬埔寨瑞爾',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => '科摩羅法郎',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => '北韓元',
        ],
        'KRH' => [
            0 => 'KRH',
            1 => '南韓圜',
        ],
        'KRO' => [
            0 => 'KRO',
            1 => '南韓圓',
        ],
        'KRW' => [
            0 => '￦',
            1 => '韓元',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => '科威特第納爾',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => '開曼群島元',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => '哈薩克堅戈',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => '寮國基普',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => '黎巴嫩鎊',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => '斯里蘭卡盧比',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => '賴比瑞亞元',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => '賴索托洛蒂',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => '立陶宛立特',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => '立陶宛特羅',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => '盧森堡可兌換法郎',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => '盧森堡法郎',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => '盧森堡金融法郎',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => '拉脫維亞拉特銀幣',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => '拉脫維亞盧布',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => '利比亞第納爾',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => '摩洛哥迪拉姆',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => '摩洛哥法郎',
        ],
        'MCF' => [
            0 => 'MCF',
            1 => '摩納哥法郎',
        ],
        'MDC' => [
            0 => 'MDC',
            1 => '摩爾多瓦券',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => '摩杜雲列伊',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => '馬達加斯加阿里亞里',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => '馬達加斯加法郎',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => '馬其頓第納爾',
        ],
        'MKN' => [
            0 => 'MKN',
            1 => '馬其頓第納爾 (1992–1993)',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => '馬里法郎',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => '緬甸元',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => '蒙古圖格里克',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => '澳門元',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => '茅利塔尼亞烏吉亞 (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => '茅利塔尼亞烏吉亞',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => '馬爾他里拉',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => '馬爾他鎊',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => '模里西斯盧比',
        ],
        'MVP' => [
            0 => 'MVP',
            1 => '馬爾地夫盧比',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => '馬爾地夫盧非亞',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => '馬拉維克瓦查',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => '墨西哥披索',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => '墨西哥銀披索 (1861–1992)',
        ],
        'MXV' => [
            0 => 'MXV',
            1 => '墨西哥轉換單位 (UDI)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => '馬來西亞令吉',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => '莫三比克埃斯庫多',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => '莫三比克梅蒂卡爾 (1980–2006)',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => '莫三比克梅蒂卡爾',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => '納米比亞元',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => '奈及利亞奈拉',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => '尼加拉瓜科多巴',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => '尼加拉瓜金科多巴',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => '荷蘭盾',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => '挪威克朗',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => '尼泊爾盧比',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => '紐西蘭幣',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => '阿曼里亞爾',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => '巴拿馬巴波亞',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => '祕魯因蒂',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => '秘魯太陽幣',
        ],
        'PES' => [
            0 => 'PES',
            1 => '秘魯太陽幣 (1863–1965)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => '巴布亞紐幾內亞基那',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => '菲律賓披索',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => '巴基斯坦盧比',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => '波蘭茲羅提',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => '波蘭茲羅提 (1950–1995)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => '葡萄牙埃斯庫多',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => '巴拉圭瓜拉尼',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => '卡達里亞爾',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => '羅德西亞元',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => '舊羅馬尼亞列伊',
        ],
        'RON' => [
            0 => 'RON',
            1 => '羅馬尼亞列伊',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => '塞爾維亞戴納',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => '俄羅斯盧布',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => '俄羅斯盧布 (1991–1998)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => '盧安達法郎',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => '沙烏地里亞爾',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => '索羅門群島元',
        ],
        'SCR' => [
            0 => 'SCR',
            1 => '塞席爾盧比',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => '蘇丹第納爾',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => '蘇丹鎊',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => '舊蘇丹鎊',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => '瑞典克朗',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => '新加坡幣',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => '聖赫勒拿鎊',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => '斯洛維尼亞托勒',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => '斯洛伐克克朗',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => '獅子山利昂',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => '索馬利亞先令',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => '蘇利南元',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => '蘇利南基爾',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => '南蘇丹鎊',
        ],
        'STD' => [
            0 => 'STD',
            1 => '聖多美島和普林西比島多布拉 (1977–2017)',
        ],
        'STN' => [
            0 => 'STN',
            1 => '聖多美島和普林西比島多布拉',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => '蘇聯盧布',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => '薩爾瓦多科郎',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => '敘利亞鎊',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => '史瓦濟蘭里朗吉尼',
        ],
        'THB' => [
            0 => 'THB',
            1 => '泰銖',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => '塔吉克盧布',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => '塔吉克索莫尼',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => '土庫曼馬納特 (1993–2009)',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => '土庫曼馬納特',
        ],
        'TND' => [
            0 => 'TND',
            1 => '突尼西亞第納爾',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => '東加潘加',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => '帝汶埃斯庫多',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => '土耳其里拉 (1922–2005)',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => '土耳其里拉',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => '千里達及托巴哥元',
        ],
        'TWD' => [
            0 => '$',
            1 => '新台幣',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => '坦尚尼亞先令',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => '烏克蘭格里夫納',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => '烏克蘭卡本瓦那茲',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => '烏干達先令 (1966–1987)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => '烏干達先令',
        ],
        'USD' => [
            0 => 'US$',
            1 => '美元',
        ],
        'USN' => [
            0 => 'USN',
            1 => '美元（次日）',
        ],
        'USS' => [
            0 => 'USS',
            1 => '美元（當日）',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => '烏拉圭披索（指數單位）',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => '烏拉圭披索 (1975–1993)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => '烏拉圭披索',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => '烏茲別克索姆',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => '委內瑞拉玻利瓦 (1871–2008)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => '委內瑞拉玻利瓦 (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => '委內瑞拉玻利瓦',
        ],
        'VND' => [
            0 => '₫',
            1 => '越南盾',
        ],
        'VNN' => [
            0 => 'VNN',
            1 => '越南盾 (1978–1985)',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => '萬那杜瓦圖',
        ],
        'WST' => [
            0 => 'WST',
            1 => '西薩摩亞塔拉',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => '法郎 (CFA–BEAC)',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => '格瑞那達元',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => '歐洲貨幣單位 (XEU)',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => '法國金法郎',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => '法國法郎 (UIC)',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => '法郎 (CFA–BCEAO)',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => '法郎 (CFP)',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'RINET 基金',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => '葉門第納爾',
        ],
        'YER' => [
            0 => 'YER',
            1 => '葉門里亞爾',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => '南斯拉夫第納爾硬幣',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => '南斯拉夫挪威亞第納爾',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => '南斯拉夫可轉換第納爾',
        ],
        'YUR' => [
            0 => 'YUR',
            1 => '南斯拉夫改革第納爾 (1992–1993)',
        ],
        'ZAL' => [
            0 => 'ZAL',
            1 => '南非蘭特（金融）',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => '南非蘭特',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => '尚比亞克瓦查 (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => '尚比亞克瓦查',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => '薩伊新扎伊爾',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => '薩伊扎伊爾',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => '辛巴威元 (1980–2008)',
        ],
        'ZWL' => [
            0 => 'ZWL',
            1 => '辛巴威元 (2009)',
        ],
        'ZWR' => [
            0 => 'ZWR',
            1 => '辛巴威元 (2008)',
        ],
    ],
];
